@@ -96,6 +96,7 @@
 #define HAVE_SYS_UN_H 1
 /* #undef HAVE_SYS_VADVISE_H */
 #define HAVE_SYS_STATVFS_H 1
+#define HAVE_UCONTEXT_H 1
 #define HAVE_TERM_H 1
 /* #undef HAVE_TERMBITS_H */
 #define HAVE_TERMIOS_H 1
@@ -297,7 +298,6 @@
 /* #undef HAVE_THR_YIELD */
 #define HAVE_TIME 1
 #define HAVE_TIMES 1
-/* #undef HAVE_UCONTEXT */
 #define HAVE_VALLOC 1
 #define HAVE_VIDATTR 1
 #define HAVE_VIO_READ_BUFF 1
@@ -640,16 +640,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 1
-#define MYSQL_VERSION_PATCH 10
+#define MYSQL_VERSION_PATCH 13
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.1.10"
+#define PACKAGE_STRING "MySQL Server 10.1.13"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.1.10"
-#define VERSION "10.1.10"
+#define PACKAGE_VERSION "10.1.13"
+#define VERSION "10.1.13"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
